@@ -9,6 +9,8 @@
 #include <stdio.h>
 #include <errno.h>
 #include <fcntl.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include <X11/Xlib.h>
 #include <X11/xpm.h>
@@ -230,6 +232,7 @@ void initializeWindow(int argc, char** argv,
 			char * redcolor,
 			char * slidercolor,
 			char * sliderbgcolor,
+			char * app_name,
 			int withdrawn,
 			int iconic,
 			int embossed)
@@ -240,7 +243,6 @@ void initializeWindow(int argc, char** argv,
 	Pixel back_pix, fore_pix;
 	XSizeHints SizeHints;
 	XTextProperty title;
-	char * app_name = "asapm";
 	XClassHint classHint;
 	int gravity;
 	XWMHints WmHints;
