@@ -1,6 +1,6 @@
 /*
- * asapm is the APM (Advanced Power Management) monitor utility for X Windows
- * Copyright (c) 1998-2000  Albert "Tigr" Dorofeev <albert@tigr.net>
+ * asapm is the APM and ACPI monitor utility for X Windows
+ * Copyright (c) 1998-2005  Albert "Tigr" Dorofeev <albert@tigr.net>
  * For the updates see http://www.tigr.net/
  *
  * This software is distributed under GPL. For details see LICENSE file.
@@ -21,7 +21,14 @@
 
 struct apm_state state;
 
+char	application_name[256];
+
 char	apm_device_file[256];
+char	acpi_device_dir[256];
+char	acpi_battery_name[256];
+
+int	force_acpi = 0;
+int	force_apm = 0;
 
 char    statuscolor[50],
         greencolor[50],
@@ -51,7 +58,14 @@ char    mainGeometry[50];
 /* This function sets the default values to global variables */
 void defaults()
 {
+	safecopy(application_name, "asapm", 256);
+
 	safecopy(apm_device_file, APM_PROC, 256);
+	safecopy(acpi_device_dir, ACPI_PROC, 256);
+	safecopy(acpi_battery_name, "", 256);
+
+	force_acpi = 0;
+	force_apm = 0;
 
         /* I use RoyalBlue personally, but the author might not like me */
         /* arbitrary aesthetic changes to his progam.  ;)  --Dagmar */
@@ -87,6 +101,7 @@ void usage()
         printf("Usage : asapm [options ...]\n\n");
         printf("-V              print version and exit\n");
         printf("-h -H -help     print this message\n");
+        printf("-name <name>    use the specified name for the window\n");
         printf("-rc <file>      use the specified resource file\n");
         printf("-u <secs>       the update interval in seconds\n");
         printf("-display <name> the name of the display to use\n");
@@ -95,7 +110,10 @@ void usage()
         printf("-withdrawn      start in withdrawn shape (for WindowMaker)\n");
         printf("-iconic         start iconized\n");
         printf("-standout       standing out rather than being pushed in\n");
-	printf("-dev <device>	use the specified file as APM device\n");
+	printf("-dev <device>	use the specified file as APM/ACPI device location\n");
+	printf("-bat <name>	use the specified battery name (ACPI only)\n");
+	printf("-acpi		force the use of ACPI only\n");
+	printf("-apm		force the use of APM only\n");
 	printf("-fail 		fail if cannot read the APM device\n");
         printf("-[no]syslevels  [do not] use system - defined levels for battery status\n");
         printf("-[no]systime    [calculate] or not battery life time instead of\n");
@@ -113,7 +131,7 @@ void usage()
 /* print the version of the tool */
 void version()
 {
-        printf("asapm : Advanced Power Management monitor version 2.13\n");
+        printf("asapm : Power Management (APM / ACPI) monitor version 3.1\n");
 }               
 
 /*
@@ -181,10 +199,21 @@ void    parsecmdline(int argc, char *argv[])
                                 state.system_time=1;
                         } else if (!strncmp(argument,"-nosystime",10)) {
                                 state.system_time=0;
+                        } else if (!strncmp(argument,"-acpi",5)) {
+                                force_acpi=1;
+				force_apm=0;
+                        } else if (!strncmp(argument,"-apm",4)) {
+                                force_acpi=0;
+				force_apm=1;
                         } else if (!strncmp(argument,"-dev",4)) {
                                 if (++i >= argc)
                                         usage();
                                 safecopy(apm_device_file, argv[i], 256);
+                                safecopy(acpi_device_dir, argv[i], 256);
+                        } else if (!strncmp(argument,"-bat",4)) {
+                                if (++i >= argc)
+                                        usage();
+                                safecopy(acpi_battery_name, argv[i], 256);
                         } else if (!strncmp(argument,"-fail",5)) {
                                 state.fail=1;
                         } else if (!strncmp(argument,"-position",9)) {
@@ -215,6 +244,10 @@ void    parsecmdline(int argc, char *argv[])
                                 if (++i >= argc)
                                         usage();
                                 safecopy(sliderbgcolor, argv[i], 50);
+                        } else if (!strncmp(argument,"-name",5)) {
+                                if (++i >= argc)
+                                        usage();
+                                safecopy(application_name, argv[i], 256);
                         } else if (!strncmp(argument,"-display",8)) {
                                 if (++i >= argc)
                                         usage();
@@ -278,6 +311,7 @@ int main(int argc, char *argv[])
 			redcolor,
 			slidercolor,
 			sliderbgcolor,
+			application_name,
 			withdrawn,
 			iconic,
 			embossed);
